@@ -1,12 +1,21 @@
+from __future__ import unicode_literals
+
+import datetime
 import functools
+import operator
+
 from django.core.exceptions import ImproperlyConfigured
 from django.db.models import Q
-import datetime
-import operator
+
+import six
+from six.moves import reduce
+
 from ..compat import ContextMixin
 
-VALID_STRING_LOOKUPS = ('iexact', 'contains', 'icontains', 'startswith', 'istartswith', 'endswith', 'iendswith',
-    'search', 'regex', 'iregex')
+
+VALID_STRING_LOOKUPS = (
+    'iexact', 'contains', 'icontains', 'startswith', 'istartswith', 'endswith',
+    'iendswith', 'search', 'regex', 'iregex')
 
 
 class SearchableListMixin(object):
@@ -39,11 +48,11 @@ class SearchableListMixin(object):
     def get_search_fields_with_filters(self):
         fields = []
         for sf in self.search_fields:
-            if isinstance(sf, basestring):
+            if isinstance(sf, six.string_types):
                 fields.append((sf, 'icontains', ))
             else:
                 if self.check_lookups and sf[1] not in VALID_STRING_LOOKUPS:
-                    raise ValueError(u'Invalid string lookup - %s' % sf[1])
+                    raise ValueError('Invalid string lookup - %s' % sf[1])
                 fields.append(sf)
         return fields
 
@@ -85,6 +94,10 @@ class SearchableListMixin(object):
 
 class SortHelper(object):
     def __init__(self, request, sort_fields_aliases, sort_param_name, sort_type_param_name):
+        # Create a list from sort_fields_aliases, in case it is a generator,
+        # since we want to iterate through it multiple times.
+        sort_fields_aliases = list(sort_fields_aliases)
+
         self.initial_params = request.GET.copy()
         self.sort_fields = dict(sort_fields_aliases)
         self.inv_sort_fields = dict((v, k) for k, v in sort_fields_aliases)
