@@ -5,6 +5,7 @@ from django.forms.formsets import formset_factory
 from django.forms.models import modelformset_factory
 from django.forms import models as model_forms
 from django.forms import ValidationError
+from .compat import ContextMixin
 
 
 class FormProvider(object):
@@ -40,7 +41,7 @@ class FormProvider(object):
         return form
 
 
-class MultiFormMixin(object):
+class MultiFormMixin(ContextMixin):
     """
     Handle multiple forms in a single view
     """
@@ -101,9 +102,6 @@ class MultiFormMixin(object):
             })
         return kwargs
 
-    def get_context_data(self, **kwargs):
-        return kwargs
-
     def get_success_url(self):
         if self.success_url:
             url = self.success_url
