@@ -1,19 +1,23 @@
+from __future__ import unicode_literals
+
 import datetime
-from django.core.exceptions import ImproperlyConfigured
-from django.forms import ValidationError
-from django.test import TestCase
-from django.utils.unittest import expectedFailure
-from models import Item, Order, Tag, Event
 from decimal import Decimal as D
 
+from django.core.exceptions import ImproperlyConfigured
+from django.forms import ValidationError
+from django.test import TransactionTestCase
+from django.utils.unittest import expectedFailure
 
-class FormSetViewTests(TestCase):
+from .models import Item, Order, Tag, Event
+
+
+class FormSetViewTests(TransactionTestCase):
     urls = 'extra_views.tests.urls'
     management_data = {
-            'form-TOTAL_FORMS': u'2',
-            'form-INITIAL_FORMS': u'0',
-            'form-MAX_NUM_FORMS': u'',
-        }
+        'form-TOTAL_FORMS': '2',
+        'form-INITIAL_FORMS': '0',
+        'form-MAX_NUM_FORMS': '',
+    }
 
     def test_create(self):
         res = self.client.get('/formset/simple/')
@@ -47,11 +51,11 @@ class FormSetViewTests(TestCase):
 
     def test_invalid(self):
         data = {
-            'form-0-name': u'Joe Bloggs',
-            'form-0-city': u'',
-            'form-0-line1': u'',
-            'form-0-line2': u'',
-            'form-0-postcode': u'',
+            'form-0-name': 'Joe Bloggs',
+            'form-0-city': '',
+            'form-0-line1': '',
+            'form-0-line2': '',
+            'form-0-postcode': '',
         }
         data.update(self.management_data)
 
@@ -64,13 +68,13 @@ class FormSetViewTests(TestCase):
         self.assertEqual(res.status_code, 200)
 
 
-class ModelFormSetViewTests(TestCase):
+class ModelFormSetViewTests(TransactionTestCase):
     urls = 'extra_views.tests.urls'
     management_data = {
-            'form-TOTAL_FORMS': u'2',
-            'form-INITIAL_FORMS': u'0',
-            'form-MAX_NUM_FORMS': u'',
-        }
+        'form-TOTAL_FORMS': '2',
+        'form-INITIAL_FORMS': '0',
+        'form-MAX_NUM_FORMS': '',
+    }
 
     def test_create(self):
         res = self.client.get('/modelformset/simple/')
@@ -99,7 +103,7 @@ class ModelFormSetViewTests(TestCase):
             'form-0-status': 0,
         }
         data.update(self.management_data)
-        data['form-TOTAL_FORMS'] = u'1'
+        data['form-TOTAL_FORMS'] = '1'
         res = self.client.post('/modelformset/simple/', data, follow=True)
         self.assertEqual(res.status_code, 200)
         self.assertEquals(Item.objects.all().count(), 1)
@@ -117,13 +121,13 @@ class ModelFormSetViewTests(TestCase):
         self.assertEquals(len(res.context['object_list']), 10)
 
 
-class InlineFormSetViewTests(TestCase):
+class InlineFormSetViewTests(TransactionTestCase):
     urls = 'extra_views.tests.urls'
     management_data = {
-            'items-TOTAL_FORMS': u'2',
-            'items-INITIAL_FORMS': u'0',
-            'items-MAX_NUM_FORMS': u'',
-        }
+        'items-TOTAL_FORMS': '2',
+        'items-INITIAL_FORMS': '0',
+        'items-MAX_NUM_FORMS': '',
+    }
 
     def test_create(self):
         order = Order(name='Dummy Order')
@@ -178,7 +182,7 @@ class InlineFormSetViewTests(TestCase):
         self.assertEquals(1, order.items.count())
 
 
-class GenericInlineFormSetViewTests(TestCase):
+class GenericInlineFormSetViewTests(TransactionTestCase):
     urls = 'extra_views.tests.urls'
 
     def test_get(self):
@@ -211,7 +215,7 @@ class GenericInlineFormSetViewTests(TestCase):
         data = {
             'tests-tag-content_type-object_id-TOTAL_FORMS': 3,
             'tests-tag-content_type-object_id-INITIAL_FORMS': 1,
-            'tests-tag-content_type-object_id-MAX_NUM_FORMS': u'',
+            'tests-tag-content_type-object_id-MAX_NUM_FORMS': '',
             'tests-tag-content_type-object_id-0-name': 'Updated',
             'tests-tag-content_type-object_id-0-id': 1,
             'tests-tag-content_type-object_id-1-DELETE': True,
@@ -233,7 +237,7 @@ class GenericInlineFormSetViewTests(TestCase):
         data = {
             'tests-tag-content_type-object_id-TOTAL_FORMS': 3,
             'tests-tag-content_type-object_id-INITIAL_FORMS': 1,
-            'tests-tag-content_type-object_id-MAX_NUM_FORMS': u'',
+            'tests-tag-content_type-object_id-MAX_NUM_FORMS': '',
             'tests-tag-content_type-object_id-0-name': 'Updated',
             'tests-tag-content_type-object_id-0-id': 1,
             'tests-tag-content_type-object_id-1-name': 'Tag 2',
@@ -245,7 +249,7 @@ class GenericInlineFormSetViewTests(TestCase):
         self.assertEquals(3, Tag.objects.count())
 
 
-class ModelWithInlinesTests(TestCase):
+class ModelWithInlinesTests(TransactionTestCase):
     urls = 'extra_views.tests.urls'
 
     def test_create(self):
@@ -254,20 +258,20 @@ class ModelWithInlinesTests(TestCase):
         self.assertEquals(0, Tag.objects.count())
 
         data = {
-            'name': u'Dummy Order',
-            'items-TOTAL_FORMS': u'2',
-            'items-INITIAL_FORMS': u'0',
-            'items-MAX_NUM_FORMS': u'',
+            'name': 'Dummy Order',
+            'items-TOTAL_FORMS': '2',
+            'items-INITIAL_FORMS': '0',
+            'items-MAX_NUM_FORMS': '',
             'items-0-name': 'Bubble Bath',
             'items-0-sku': '1234567890123',
             'items-0-price': D('9.99'),
             'items-0-status': 0,
-            'items-0-order': u'',
+            'items-0-order': '',
             'items-1-DELETE': True,
             'tests-tag-content_type-object_id-TOTAL_FORMS': 2,
             'tests-tag-content_type-object_id-INITIAL_FORMS': 0,
-            'tests-tag-content_type-object_id-MAX_NUM_FORMS': u'',
-            'tests-tag-content_type-object_id-0-name': u'Test',
+            'tests-tag-content_type-object_id-MAX_NUM_FORMS': '',
+            'tests-tag-content_type-object_id-0-name': 'Test',
             'tests-tag-content_type-object_id-1-DELETE': True,
         }
 
@@ -287,9 +291,9 @@ class ModelWithInlinesTests(TestCase):
 
     def test_validation(self):
         data = {
-            'items-TOTAL_FORMS': u'2',
-            'items-INITIAL_FORMS': u'0',
-            'items-MAX_NUM_FORMS': u'',
+            'items-TOTAL_FORMS': '2',
+            'items-INITIAL_FORMS': '0',
+            'items-MAX_NUM_FORMS': '',
             'items-0-name': 'Test Item 1',
             'items-0-sku': '',
             'items-0-price': '',
@@ -303,8 +307,8 @@ class ModelWithInlinesTests(TestCase):
             'items-1-DELETE': True,
             'tests-tag-content_type-object_id-TOTAL_FORMS': 2,
             'tests-tag-content_type-object_id-INITIAL_FORMS': 0,
-            'tests-tag-content_type-object_id-MAX_NUM_FORMS': u'',
-            'tests-tag-content_type-object_id-0-name': u'Test',
+            'tests-tag-content_type-object_id-MAX_NUM_FORMS': '',
+            'tests-tag-content_type-object_id-0-name': 'Test',
             'tests-tag-content_type-object_id-1-DELETE': True,
         }
 
@@ -332,10 +336,10 @@ class ModelWithInlinesTests(TestCase):
         self.assertEquals('Item 0', order.items.all()[0].name)
 
         data = {
-            'name': u'Dummy Order',
-            'items-TOTAL_FORMS': u'4',
-            'items-INITIAL_FORMS': u'2',
-            'items-MAX_NUM_FORMS': u'',
+            'name': 'Dummy Order',
+            'items-TOTAL_FORMS': '4',
+            'items-INITIAL_FORMS': '2',
+            'items-MAX_NUM_FORMS': '',
             'items-0-name': 'Bubble Bath',
             'items-0-sku': '1234567890123',
             'items-0-price': D('9.99'),
@@ -356,12 +360,12 @@ class ModelWithInlinesTests(TestCase):
             'items-3-DELETE': True,
             'tests-tag-content_type-object_id-TOTAL_FORMS': 3,
             'tests-tag-content_type-object_id-INITIAL_FORMS': 1,
-            'tests-tag-content_type-object_id-MAX_NUM_FORMS': u'',
-            'tests-tag-content_type-object_id-0-name': u'Test',
+            'tests-tag-content_type-object_id-MAX_NUM_FORMS': '',
+            'tests-tag-content_type-object_id-0-name': 'Test',
             'tests-tag-content_type-object_id-0-id': 1,
             'tests-tag-content_type-object_id-0-DELETE': True,
-            'tests-tag-content_type-object_id-1-name': u'Test 2',
-            'tests-tag-content_type-object_id-2-name': u'Test 3',
+            'tests-tag-content_type-object_id-1-name': 'Test 2',
+            'tests-tag-content_type-object_id-2-name': 'Test 3',
         }
 
         res = self.client.post('/inlines/1/', data, follow=True)
@@ -378,13 +382,13 @@ class ModelWithInlinesTests(TestCase):
         order.save()
 
         data = {
-            'name': u'Dummy Order',
-            'items-TOTAL_FORMS': u'0',
-            'items-INITIAL_FORMS': u'0',
-            'items-MAX_NUM_FORMS': u'',
-            'tests-tag-content_type-object_id-TOTAL_FORMS': u'0',
-            'tests-tag-content_type-object_id-INITIAL_FORMS': u'0',
-            'tests-tag-content_type-object_id-MAX_NUM_FORMS': u'',
+            'name': 'Dummy Order',
+            'items-TOTAL_FORMS': '0',
+            'items-INITIAL_FORMS': '0',
+            'items-MAX_NUM_FORMS': '',
+            'tests-tag-content_type-object_id-TOTAL_FORMS': '0',
+            'tests-tag-content_type-object_id-INITIAL_FORMS': '0',
+            'tests-tag-content_type-object_id-MAX_NUM_FORMS': '',
         }
 
         res = self.client.post('/inlines/1/', data, follow=True)
@@ -394,7 +398,7 @@ class ModelWithInlinesTests(TestCase):
         self.assertTrue(order.action_on_save)
 
 
-class CalendarViewTests(TestCase):
+class CalendarViewTests(TransactionTestCase):
     urls = 'extra_views.tests.urls'
 
     def test_create(self):
@@ -405,53 +409,54 @@ class CalendarViewTests(TestCase):
         self.assertEqual(res.status_code, 200)
 
 
-class SearchableListTests(TestCase):
+class SearchableListTests(TransactionTestCase):
     urls = 'extra_views.tests.urls'
 
     def setUp(self):
         order = Order(name='Dummy Order')
         order.save()
-        Item.objects.create(sku='1A', name='test A', order=order, price=0, date_placed=datetime.date(2012, 01, 01))
-        Item.objects.create(sku='1B', name='test B', order=order, price=0, date_placed=datetime.date(2012, 02, 01))
-        Item.objects.create(sku='C', name='test', order=order, price=0, date_placed=datetime.date(2012, 03, 01))
+        Item.objects.create(sku='1A', name='test A', order=order, price=0, date_placed=datetime.date(2012, 1, 1))
+        Item.objects.create(sku='1B', name='test B', order=order, price=0, date_placed=datetime.date(2012, 2, 1))
+        Item.objects.create(sku='C', name='test', order=order, price=0, date_placed=datetime.date(2012, 3, 1))
 
     def test_search(self):
-        res = self.client.get('/searchable/', data={'q':'1A test'})
+        res = self.client.get('/searchable/', data={'q': '1A test'})
         self.assertEqual(res.status_code, 200)
         self.assertEqual(1, len(res.context['object_list']))
 
-        res = self.client.get('/searchable/', data={'q':'1Atest'})
+        res = self.client.get('/searchable/', data={'q': '1Atest'})
         self.assertEqual(res.status_code, 200)
         self.assertEqual(0, len(res.context['object_list']))
 
         # date search
-        res = self.client.get('/searchable/', data={'q':'01.01.2012'})
+        res = self.client.get('/searchable/', data={'q': '01.01.2012'})
         self.assertEqual(res.status_code, 200)
         self.assertEqual(1, len(res.context['object_list']))
 
-        res = self.client.get('/searchable/', data={'q':'02.01.2012'})
+        res = self.client.get('/searchable/', data={'q': '02.01.2012'})
         self.assertEqual(res.status_code, 200)
         self.assertEqual(0, len(res.context['object_list']))
 
         # search query provided by view's get_search_query method
-        res = self.client.get('/searchable/predefined_query/', data={'q':'idoesntmatter'})
+        res = self.client.get('/searchable/predefined_query/', data={'q': 'idoesntmatter'})
         self.assertEqual(res.status_code, 200)
         self.assertEqual(1, len(res.context['object_list']))
 
         # exact search query
-        res = self.client.get('/searchable/exact_query/', data={'q':'test'})
+        res = self.client.get('/searchable/exact_query/', data={'q': 'test'})
         self.assertEqual(res.status_code, 200)
         self.assertEqual(1, len(res.context['object_list']))
 
         # wrong lookup
         try:
-            self.assertRaises(self.client.get('/searchable/wrong_lookup/', data={'q':'test'}))
+            self.assertRaises(self.client.get('/searchable/wrong_lookup/', data={'q': 'test'}))
             error = False
         except ValueError:
             error = True
         self.assertTrue(error)
 
-class SortableViewTest(TestCase):
+
+class SortableViewTest(TransactionTestCase):
     urls = 'extra_views.tests.urls'
 
     def setUp(self):
